logging

package
v0.0.0-...-2803a0f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 27, 2026 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RequestLogf

func RequestLogf(ctx *goproxy.ProxyCtx, format string, v ...any)

RequestLogf builds a log entry from format and v according to the semantics of fmt.Sprintf and logs it. All sequences of newlines and/or carriage returns in the resulting entry are replaced with a space, any trailing spaces are removed, and the entry is logged with a single trailing newline. If p is given, the logged line is prefixed with a three-digit representation of p.Session.

func RequestMultilineLogf

func RequestMultilineLogf(ctx *goproxy.ProxyCtx, format string, v ...any)

RequestMultilineLogf builds a log entry from format and v according to the semantics of fmt.Sprintf and logs it. If the resulting entry contains newlines and/or carriage returns, they are preserved. The resulting entry is truncated to 1024 bytes and it is logged with a single trailing newline. If p is given, the first line logged is prefixed with a three-digit representation of p.Session.

Types

This section is empty.

Jump to