Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RequestLogf ¶
RequestLogf builds a log entry from format and v according to the semantics of fmt.Sprintf and logs it. All sequences of newlines and/or carriage returns in the resulting entry are replaced with a space, any trailing spaces are removed, and the entry is logged with a single trailing newline. If p is given, the logged line is prefixed with a three-digit representation of p.Session.
func RequestMultilineLogf ¶
RequestMultilineLogf builds a log entry from format and v according to the semantics of fmt.Sprintf and logs it. If the resulting entry contains newlines and/or carriage returns, they are preserved. The resulting entry is truncated to 1024 bytes and it is logged with a single trailing newline. If p is given, the first line logged is prefixed with a three-digit representation of p.Session.
Types ¶
This section is empty.